/*
 *   Copyright (C) 2025 CESNET
 *
 * Invenio RDM Records is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

@import "@uppy/core/dist/style.min.css";
@import "@uppy/dashboard/dist/style.min.css";
@import "@uppy/image-editor/dist/style.min.css";

.uppy-Dashboard-AddFiles {
  padding: 1.2rem;
}
.uppy-Dashboard-AddFiles-info {
  display: block;
}

.uppy-Dashboard-note {
  padding-top: 3rem;
}

.uppy-Dashboard-inner {
  border-radius: 0 0 5px 5px;
}

.uppy-Dashboard-innerWrap {
  height: 350px;

  &:has(#uppy-DashboardContent-panel--editor) {
    height: 500px;
  }
}

.uppy-DashboardContent-bar, .uppy-StatusBar {
  z-index: 10;
}
